M step of the EM algorithm for fitting homogeneous multivariate Markov switching auto-regressive models with constraints on VAR models, called in fit.MSAR. Maximum likelihood is used. Matrices A and sigma are diagonal by blocks.
Mstep.hh.MSAR.with.constraints(data, theta, FB, K, d.y)array of univariate or multivariate series with dimension T x N.samples x d. T: number of time steps of each sample, N.samples: number of realisations of the same stationary process, d: dimension.
model's parameter; object of class MSAR. See also init.theta.MSAR.
Forward-Backward results, obtained by calling Estep.MSAR function
number of sites. For instance, if one considers wind at k locations, K=k. Or more generally number of independent groups of components.
dimension in each sites. For instance, if one considers only wind intensity than d.y = 1; but, if one considers cartesian components of wind, then d.y =2.
intercepts
AR coefficients
variance of innovation
prior probabilities
transition matrix
Mstep.hh.MSAR, fit.MSAR, Mstep.hh.SCAD.MSAR