Learn R Programming

NHMSAR (version 1.19)

Mstep.hh.reduct.MSAR: M step of the EM algorithm for fitting homogeneous Markov switching auto-regressive models with constraints on the matrices.

Description

M step of the EM algorithm for fitting homogeneous Markov switching auto-regressive model swith constraints on the matrices, called in fit.MSAR. The matrices are constrained to have the same pattern ()zeros and non zeros coefficients) as the initial matrices.

Usage

Mstep.hh.reduct.MSAR(data, theta, FB, sigma.diag=FALSE)

Arguments

data

array of univariate or multivariate series with dimension T*N.samples*d. T: number of time steps of each sample, N.samples: number of realisations of the same stationary process, d: dimension.

theta

model's parameter; object of class MSAR. See also init.theta.MSAR.

FB

Forward-Backward results, obtained by calling Estep.MSAR function

sigma.diag

if TRUE the innovation covariance matrices are diagonal.

Value

A list containing

A0

intercepts

A

AR coefficients

sigma

variance of innovation

prior

prior probabilities

transmat

transition matrix

References

Ailliot P., Monbet V., (2012), Markov switching autoregressive models for wind time series. Environmental Modelling & Software, 30, pp 92-101.

See Also

Mstep.hh.MSAR, fit.MSAR, Estep.MSAR, Mstep.classif