Learn R Programming

NHMSAR (version 1.4)

Mstep.hh.MSAR.with.constraints:

Description

M step of the EM algorithm for fitting homogeneous multivariate Markov switching auto-regressive models with constraints on VAR models, called in fit.MSAR. Maximum likelihood is used. Matrices A and sigma are diagonal by blocks.

Usage

Mstep.hh.MSAR.with.constraints(data, theta, FB, K, d.y)

Arguments

data
array of univariate or multivariate series with dimension T x N.samples x d. T: number of time steps of each sample, N.samples: number of realisations of the same stationary process, d: dimension.
theta
model's parameter; object of class MSAR. See also init.theta.MSAR.
FB
Forward-Backward results, obtained by calling Estep.MSAR function
K
number of sites. For instance, if one considers wind at k locations, K=k. Or more generally number of independent groups of components.
d.y
dimension in each sites. For instance, if one considers only wind intensity than d.y = 1; but, if one considers cartesian components of wind, then d.y =2.

Value

A0
intercepts
A
AR coefficients
sigma
variance of innovation
prior
prior probabilities
transmat
transition matrix

See Also

Mstep.hh.MSAR, fit.MSAR, Mstep.hh.SCAD.MSAR