M step of the EM algorithm for fitting homogeneous multivariate Markov switching auto-regressive models with penalization of parameters of the VAR(1) models, called in fit.MSAR. Penalized maximum likelihood is used. Penalization may be add to the autoregressive matrices of order 1 and to the precision matrices (inverse of variance of innovation).
Mstep.hh.lasso.MSAR(data, theta, FB)array of univariate or multivariate series with dimension T x N.samples x d. T: number of time steps of each sample, N.samples: number of realisations of the same stationary process, d: dimension.
model's parameter; object of class MSAR. See also init.theta.MSAR.
Forward-Backward results, obtained by calling Estep.MSAR function
intercepts
AR coefficients
variance of innovation
inverse of variance of innovation
prior probabilities
transition matrix
The lars algorithm of pagkage lars is used.
Efron, B., Hastie, T., Johnstone, I., Tibshirani, R., et al. (2004). Least angle regression. The Annals of statistics, 32(2):407-499.
Mstep.hh.MSAR, fit.MSAR