M step of the EM algorithm for fitting homogeneous Markov switching auto-regressive model swith constraints on the matrices, called in fit.MSAR. The matrices are constrained to have the same pattern ()zeros and non zeros coefficients) as the initial matrices.
Mstep.hh.reduct.MSAR(data, theta, FB, sigma.diag=FALSE)array of univariate or multivariate series with dimension T*N.samples*d. T: number of time steps of each sample, N.samples: number of realisations of the same stationary process, d: dimension.
model's parameter; object of class MSAR. See also init.theta.MSAR.
Forward-Backward results, obtained by calling Estep.MSAR function
if TRUE the innovation covariance matrices are diagonal.
A list containing
intercepts
AR coefficients
variance of innovation
prior probabilities
transition matrix
Ailliot P., Monbet V., (2012), Markov switching autoregressive models for wind time series. Environmental Modelling & Software, 30, pp 92-101.
Mstep.hh.MSAR, fit.MSAR, Estep.MSAR, Mstep.classif